pub enum Error {
AppCreation(Box<dyn Error + Send + Sync>),
OpenGL(PainterError),
Wgpu(WgpuError),
}Expand description
The different problems that can occur when trying to run eframe.
Variants
AppCreation(Box<dyn Error + Send + Sync>)
Something went wrong in user code when creating the app.
OpenGL(PainterError)
An error from [glutin] when using glow.
Wgpu(WgpuError)
An error from wgpu.