pub struct EframeWinitApplication<'a> { /* private fields */ }Expand description
A proxy to the eframe application that implements ApplicationHandler.
This can be run directly on your own EventLoop by itself or with other
windows you manage outside of eframe.
Implementations
Sourceimpl<'a> EframeWinitApplication<'a>
impl<'a> EframeWinitApplication<'a>
Sourcepub fn pump_eframe_app(
&mut self,
event_loop: &mut EventLoop<UserEvent>,
timeout: Option<Duration>,
) -> EframePumpStatus
pub fn pump_eframe_app( &mut self, event_loop: &mut EventLoop<UserEvent>, timeout: Option<Duration>, ) -> EframePumpStatus
Pump the EventLoop to check for and dispatch pending events to this application.
Returns either the exit code for the application or the final state of the ControlFlow
after all events have been dispatched in this iteration.
This is useful when your EventLoop is not the main event loop for your application.
See the external_eventloop_async example.