pub struct IconData {
pub rgba: Vec<u8>,
pub width: u32,
pub height: u32,
}
Image data for an application icon.
RGBA pixels, unmultiplied.
Image width. This should be a multiple of 4.
Image height. This should be a multiple of 4.
Performs copy-assignment from
source.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.