EventLoopBuilderHook

Type Alias EventLoopBuilderHook 

pub type EventLoopBuilderHook = Box<dyn FnOnce(&mut EventLoopBuilder<UserEvent>)>;
Hook into the building of an event loop before it is run

You can configure any platform specific details required on top of the default configuration done by EFrame.

Aliased Type

pub struct EventLoopBuilderHook(/* private fields */);