Frame

Struct Frame 

pub struct Frame { /* private fields */ }
Represents the surroundings of your app.

It provides methods to inspect the surroundings (are we on the web?), access to persistent storage, and access to the rendering backend.

Implementations

Source

impl Frame

pub fn is_web(&self) -> bool

True if you are in a web environment.

Equivalent to cfg!(target_arch = "wasm32")

pub fn info(&self) -> &IntegrationInfo

Information about the integration.

pub fn storage(&self) -> Option<&dyn Storage>

A place where you can store custom data in a way that persists when you restart the app.

pub fn storage_mut(&mut self) -> Option<&mut (dyn Storage + 'static)>

A place where you can store custom data in a way that persists when you restart the app.

pub fn winit_window(&self) -> Option<&Arc<Window>>

Access to the current winit::window::Window (i.e. the one the active viewport is rendered to).

None for headless (tests etc).

pub fn gl(&self) -> Option<&Arc<Context>>

A reference to the underlying glow (OpenGL) context.

This can be used, for instance, to:

  • Render things to offscreen buffers.
  • Read the pixel buffer from the previous frame (glow::Context::read_pixels).
  • Render things behind the egui windows.

Note that all egui painting is deferred to after the call to App::ui (egui only collects egui::Shapes and then eframe paints them all in one go later on).

To get a glow context you need to compile with the glow feature flag, and run eframe using Renderer::Glow.

pub fn register_native_glow_texture(&mut self, native: Texture) -> TextureId

Register your own glow::Texture, and then you can use the returned egui::TextureId to render your texture with egui.

This function will take the ownership of your glow::Texture, so please do not delete your glow::Texture after registering.

pub fn wgpu_render_state(&self) -> Option<&RenderState>

The underlying WGPU render state.

Only available when compiling with the wgpu feature and using Renderer::Wgpu.

Can be used to manage GPU resources for custom rendering with WGPU using egui::PaintCallbacks.

pub fn wgpu_surface_config(&self) -> Option<SurfaceConfig>

The currently-applied runtime surface config (present mode, frame latency) used by the wgpu renderer, if any.

Returns None when not using the wgpu backend.

pub fn set_wgpu_surface_config(&mut self, config: SurfaceConfig)

Set the runtime surface config (present mode, frame latency) for the wgpu renderer. The surface is reconfigured on the next paint.

No-op when not using the wgpu backend.