Struct eframe::NativeOptions
source · pub struct NativeOptions {Show 17 fields
pub viewport: ViewportBuilder,
pub vsync: bool,
pub multisampling: u16,
pub depth_buffer: u8,
pub stencil_buffer: u8,
pub hardware_acceleration: HardwareAcceleration,
pub renderer: Renderer,
pub follow_system_theme: bool,
pub default_theme: Theme,
pub run_and_return: bool,
pub event_loop_builder: Option<EventLoopBuilderHook>,
pub window_builder: Option<WindowBuilderHook>,
pub shader_version: Option<ShaderVersion>,
pub centered: bool,
pub wgpu_options: WgpuConfiguration,
pub persist_window: bool,
pub persistence_path: Option<PathBuf>,
}Expand description
Options controlling the behavior of a native window.
Additional windows can be opened using (egui viewports)egui::viewport.
Set the window title and size using Self::viewport.
Application id
egui::ViewportBuilder::with_app_id is used for determining the folder to persist the app to.
On native the path is picked using crate::storage_dir.
If you don’t set an app id, the title argument to crate::run_native
will be used as app id instead.
Fields
viewport: ViewportBuilderControls the native window of the root viewport.
This is where you set things like window title and size.
If you don’t set an icon, a default egui icon will be used.
To avoid this, set the icon to egui::IconData::default.
vsync: boolTurn on vertical syncing, limiting the FPS to the display refresh rate.
The default is true.
multisampling: u16Set the level of the multisampling anti-aliasing (MSAA).
Must be a power-of-two. Higher = more smooth 3D.
A value of 0 turns it off (default).
egui already performs anti-aliasing via “feathering”
(controlled by egui::epaint::TessellationOptions),
but if you are embedding 3D in egui you may want to turn on multisampling.
depth_buffer: u8Sets the number of bits in the depth buffer.
egui doesn’t need the depth buffer, so the default value is 0.
stencil_buffer: u8Sets the number of bits in the stencil buffer.
egui doesn’t need the stencil buffer, so the default value is 0.
hardware_acceleration: HardwareAccelerationSpecify whether or not hardware acceleration is preferred, required, or not.
Default: HardwareAcceleration::Preferred.
renderer: RendererWhat rendering backend to use.
follow_system_theme: boolTry to detect and follow the system preferred setting for dark vs light mode.
The theme will automatically change when the dark vs light mode preference is changed.
Does not work on Linux (see https://github.com/rust-windowing/winit/issues/1549).
See also Self::default_theme.
default_theme: ThemeWhich theme to use in case Self::follow_system_theme is false
or eframe fails to detect the system theme.
Default: Theme::Dark.
run_and_return: boolThis controls what happens when you close the main eframe window.
If true, execution will continue after the eframe window is closed.
If false, the app will close once the eframe window is closed.
This is true by default, and the false option is only there
so we can revert if we find any bugs.
This feature was introduced in https://github.com/emilk/egui/pull/1889.
When true, winit::platform::run_on_demand::EventLoopExtRunOnDemand is used.
When false, winit::event_loop::EventLoop::run is used.
event_loop_builder: Option<EventLoopBuilderHook>Hook into the building of an event loop before it is run.
Specify a callback here in case you need to make platform specific changes to the event loop before it is run.
Note: A NativeOptions clone will not include any event_loop_builder hook.
window_builder: Option<WindowBuilderHook>Hook into the building of a window.
Specify a callback here in case you need to make platform specific changes to the window appearance.
Note: A NativeOptions clone will not include any window_builder hook.
shader_version: Option<ShaderVersion>Needed for cross compiling for VirtualBox VMSVGA driver with OpenGL ES 2.0 and OpenGL 2.1 which doesn’t support SRGB texture. See https://github.com/emilk/egui/pull/1993.
For OpenGL ES 2.0: set this to egui_glow::ShaderVersion::Es100 to solve blank texture problem (by using the “fallback shader”).
centered: boolOn desktop: make the window position to be centered at initialization.
Platform specific:
Wayland desktop currently not supported.
wgpu_options: WgpuConfigurationConfigures wgpu instance/device/adapter/surface creation and renderloop.
persist_window: boolControls whether or not the native window position and size will be persisted (only if the “persistence” feature is enabled).
persistence_path: Option<PathBuf>The folder where eframe will store the app state. If not set, eframe will get the paths
from directories.