Struct eframe::NativeOptions
source · [−]pub struct NativeOptions {Show 21 fields
pub always_on_top: bool,
pub maximized: bool,
pub decorated: bool,
pub fullscreen: bool,
pub drag_and_drop_support: bool,
pub icon_data: Option<IconData>,
pub initial_window_pos: Option<Pos2>,
pub initial_window_size: Option<Vec2>,
pub min_window_size: Option<Vec2>,
pub max_window_size: Option<Vec2>,
pub resizable: bool,
pub transparent: bool,
pub vsync: bool,
pub multisampling: u16,
pub depth_buffer: u8,
pub stencil_buffer: u8,
pub hardware_acceleration: HardwareAcceleration,
pub renderer: Renderer,
pub follow_system_theme: bool,
pub default_theme: Theme,
pub run_and_return: bool,
}Expand description
Options controlling the behavior of a native window.
Only a single native window is currently supported.
Fields
always_on_top: boolSets whether or not the window will always be on top of other windows.
maximized: boolShow window in maximized mode
decorated: boolOn desktop: add window decorations (i.e. a frame around your app)? If false it will be difficult to move and resize the app.
fullscreen: boolStart in (borderless) fullscreen?
Default: false.
drag_and_drop_support: boolOn Windows: enable drag and drop support. Drag and drop can not be disabled on other platforms.
See winit’s documentation for information on why you might want to disable this on windows.
icon_data: Option<IconData>The application icon, e.g. in the Windows task bar etc.
This doesn’t work on Mac and on Wayland. See https://docs.rs/winit/latest/winit/window/struct.Window.html#method.set_window_icon for more.
initial_window_pos: Option<Pos2>The initial (inner) position of the native window in points (logical pixels).
initial_window_size: Option<Vec2>The initial inner size of the native window in points (logical pixels).
min_window_size: Option<Vec2>The minimum inner window size
max_window_size: Option<Vec2>The maximum inner window size
resizable: boolShould the app window be resizable?
transparent: boolOn desktop: make the window transparent.
You control the transparency with App::clear_color().
You should avoid having a egui::CentralPanel, or make sure its frame is also transparent.
vsync: boolTurn on vertical syncing, limiting the FPS to the display refresh rate.
The default is true.
multisampling: u16Set the level of the multisampling anti-aliasing (MSAA).
Must be a power-of-two. Higher = more smooth 3D.
A value of 0 turns it off (default).
egui already performs anti-aliasing via “feathering”
(controlled by [egui::epaint::TessellationOptions]),
but if you are embedding 3D in egui you may want to turn on multisampling.
depth_buffer: u8Sets the number of bits in the depth buffer.
egui doesn’t need the depth buffer, so the default value is 0.
stencil_buffer: u8Sets the number of bits in the stencil buffer.
egui doesn’t need the stencil buffer, so the default value is 0.
hardware_acceleration: HardwareAccelerationSpecify wether or not hardware acceleration is preferred, required, or not.
Default: HardwareAcceleration::Preferred.
renderer: RendererWhat rendering backend to use.
follow_system_theme: boolOnly used if the dark-light feature is enabled:
Try to detect and follow the system preferred setting for dark vs light mode.
By default, this is true on Mac and Windows, but false on Linux
due to https://github.com/frewsxcv/rust-dark-light/issues/17.
See also Self::default_theme.
default_theme: ThemeWhich theme to use in case Self::follow_system_theme is false
or the dark-light feature is disabled.
Default: Theme::Dark.
run_and_return: boolThis controls what happens when you close the main eframe window.
If true, execution will continue after the eframe window is closed.
If false, the app will close once the eframe window is closed.
This is true by default, and the false option is only there
so we can revert if we find any bugs.
This feature was introduced in https://github.com/emilk/egui/pull/1889.
When true, winit::platform::run_return::EventLoopExtRunReturn::run_return is used.
When false, winit::event_loop::EventLoop::run is used.
Implementations
sourceimpl NativeOptions
impl NativeOptions
sourcepub fn system_theme(&self) -> Option<Theme>
pub fn system_theme(&self) -> Option<Theme>
The theme used by the system.