Struct eframe::WindowInfo
source · pub struct WindowInfo {
pub position: Option<Pos2>,
pub fullscreen: bool,
pub minimized: bool,
pub maximized: bool,
pub focused: bool,
pub size: Vec2,
pub monitor_size: Option<Vec2>,
}Expand description
Information about the application’s main window, if available.
Fields
position: Option<Pos2>Coordinates of the window’s outer top left corner, relative to the top left corner of the first display.
Unit: egui points (logical pixels).
None = unknown.
fullscreen: boolAre we in fullscreen mode?
minimized: boolAre we minimized?
maximized: boolAre we maximized?
focused: boolIs the window focused and able to receive input?
This should be the same as egui::InputState::focused.
size: Vec2Window inner size in egui points (logical pixels).
monitor_size: Option<Vec2>Current monitor size in egui points (logical pixels)